@@ -1,5 +1,7 @@
+from typing import Tuple
+
 from django.contrib import admin
-from edc_model_admin import audit_fieldset_tuple
+from django_audit_fields.admin import audit_fieldset_tuple
 
 from ..admin_site import edc_pharmacy_admin
 from ..forms import DosageGuidelineForm
@@ -33,5 +35,5 @@ class DosageGuidelineAdmin(ModelAdminMixin, admin.ModelAdmin):
         audit_fieldset_tuple,
     )
 
-    list_display = ["__str__", "modified", "user_modified"]
-    search_fields = ["medication__name"]
+    list_display: Tuple[str, ...] = ("__str__", "modified", "user_modified")
+    search_fields: Tuple[str, ...] = ("medication__name",)
